.. include:: README.inc

.. toctree::
   :maxdepth: 2
   :caption: Device Types

   api.rst
   signals.rst
   base_classes.rst
   sim_types.rst

.. toctree::
   :maxdepth: 1
   :caption: Features

   mv.rst
   presets.rst
   tab.rst
   ui.rst

.. toctree::
   :maxdepth: 1
   :caption: Developer Notes

   releases.rst
   upcoming_changes.rst
